@@ -20,10 +20,10 @@
 ;; along with telega.  If not, see <http://www.gnu.org/licenses/>.
 
 ;;; ellit-org: commentary
-;; 
+;;
 ;; =telega.el= can notify you about incoming messages and calls via
 ;; D-Bus notifications, however notifications are disabled by default.
-;; 
+;;
 ;; Enable it with ~(telega-notifications-mode 1)~ or at =telega= load time:
 ;; #+begin_src emacs-lisp
 ;; (add-hook 'telega-load-hook 'telega-notifications-mode)
@@ -36,9 +36,9 @@
 (require 'telega-core)
 (require 'telega-util)
 
-(declare-function telega-chat--type "telega-chat" (chat &optional no-interpret))
+(declare-function telega-chat--type "telega-chat" (chat))
 (declare-function telega-chat-get "telega-chat" (chat-id &optional offline-p))
-(declare-function telega-chat-title "telega-chat" (chat &optional with-username))
+(declare-function telega-chat-title "telega-chat" (chat &optional no-badges))
 (declare-function telega-chat-muted-p "telega-chat" (chat))
 
 
@@ -60,28 +60,34 @@ SCOPE-TYPE is one of:
             scope))
     scope))
 
-(defun telega-chat-notification-setting (chat setting &optional default-p)
+(defun telega-chat-notification-setting (chat setting &optional topic)
   "For the CHAT return notification SETTING value.
 SETTING could be one of: `:mute_for', `:sound', `:show_preview',
 `:disable_pinned_message_notifications',
 `:disable_mention_notifications'.
-If DEFAULT-P is non-nil, then return default setting for the CHAT."
-  (let ((use-default-name
-         (intern (concat ":use_default_" (substring (symbol-name setting) 1))))
-        (not-cfg (plist-get chat :notification_settings))
-        (default-cfg nil))
-    (when (or default-p (plist-get not-cfg use-default-name))
-      (setq default-cfg
-            (telega-chat-notification-scope
-             (cl-case (telega-chat--type chat)
-               (channel
-                "notificationSettingsScopeChannelChats")
-               ((basicgroup supergroup)
-                "notificationSettingsScopeGroupChats")
-               (t
-                "notificationSettingsScopePrivateChats")))))
-
-    (plist-get (or default-cfg not-cfg) setting)))
+If TOPIC is specified, return notification setting for the given topic."
+  (cl-assert chat)
+  (let* ((use-default-name
+          (intern (concat ":use_default_" (substring (symbol-name setting) 1))))
+         (not-cfg (plist-get (or topic chat) :notification_settings))
+         (use-default-p
+          (plist-get not-cfg use-default-name)))
+    (cond ((and topic use-default-p)
+           ;; Use chat's setting
+           (telega-chat-notification-setting chat setting))
+          (use-default-p
+           ;; Use scope's setting
+           (plist-get (telega-chat-notification-scope
+                       (cl-case (telega-chat--type chat)
+                         (channel
+                          "notificationSettingsScopeChannelChats")
+                         ((basicgroup supergroup)
+                          "notificationSettingsScopeGroupChats")
+                         (t
+                          "notificationSettingsScopePrivateChats")))
+                      setting))
+          (t
+           (plist-get not-cfg setting)))))
 
 (defun telega-ins--msg-notification (msg)
   "Inserter to format MSG to notify about."
@@ -89,9 +95,9 @@ If DEFAULT-P is non-nil, then return default setting for the CHAT."
   (telega-ins--with-attrs (list :max telega-notifications-msg-body-limit
                                 :elide t)
     (let ((chat (telega-chat-get (plist-get msg :chat_id))))
-      (unless (memq (telega-chat--type chat 'raw) '(private secret))
-        (when (telega-ins--msg-sender (telega-msg-sender msg))
-          (telega-ins ": "))))
+      (unless (telega-chat-match-p chat '(type private secret bot))
+        (telega-ins--msg-sender (telega-msg-sender msg))
+        (telega-ins ": ")))
 
     (let ((telega-use-images nil))
       (telega-ins--content msg))))
@@ -102,70 +108,99 @@ SCOPE-TYPE is same an in `telega-chat-notification-scope'."
   (let* ((sconf (telega-chat-notification-scope scope-type))
          (mute-for (plist-get sconf :mute_for))
          (unmuted-p (zerop mute-for))
-         (sound (plist-get sconf :sound))
-         (preview-p (plist-get sconf :show_preview))
-         (disable-pinned-p
-          (plist-get sconf :disable_pinned_message_notifications))
-         (disable-mentions-p
-          (plist-get sconf :disable_mention_notifications)))
-    (telega-ins--button (if unmuted-p
-                            telega-symbol-heavy-checkmark
-                          telega-symbol-blank-button)
-      :value (if unmuted-p telega-mute-for-ever 0)
-      :action (apply-partially #'telega--setScopeNotificationSettings
-                               scope-type :mute_for))
-    (telega-ins " " "Show Notifications")
+         (sound-id (plist-get sconf :sound_id))
+         (preview-p (plist-get sconf :show_preview)))
+    (telega-ins--text-button (if unmuted-p
+                                 (telega-symbol 'checkbox-on)
+                               (telega-symbol 'checkbox-off))
+      'face 'telega-link
+      'action (lambda (_button)
+                (telega--setScopeNotificationSettings
+                    scope-type :mute_for (if unmuted-p telega-mute-for-ever 0))))
+    (telega-ins " " (telega-i18n "lng_settings_desktop_notify"))
     (telega-ins "\n")
 
-    (telega-ins--button (if preview-p
-                            telega-symbol-heavy-checkmark
-                          telega-symbol-blank-button)
-      :value (if preview-p :false t)
-      :action (apply-partially #'telega--setScopeNotificationSettings
-                               scope-type :show_preview))
-    (telega-ins " " "Show Preview")
+    (telega-ins--text-button (if preview-p
+                                 (telega-symbol 'checkbox-on)
+                               (telega-symbol 'checkbox-off))
+      'face 'telega-link
+      'action (lambda (_button)
+                (telega--setScopeNotificationSettings scope-type
+                  :show_preview (if preview-p :false t))))
+    (telega-ins " " (telega-i18n "lng_settings_show_preview"))
     (telega-ins "\n")
 
-    (telega-ins--button (if disable-pinned-p
-                            telega-symbol-heavy-checkmark
-                          telega-symbol-blank-button)
-      :value (if disable-pinned-p :false t)
-      :action (apply-partially #'telega--setScopeNotificationSettings
-                               scope-type :disable_pinned_message_notifications))
-    (telega-ins " " "Disable Pinned Message Notification")
-    (telega-ins "\n")
+    (let ((mute-stories-p (plist-get sconf :mute_stories)))
+      (telega-ins--text-button (if mute-stories-p
+                                   (telega-symbol 'checkbox-on)
+                                 (telega-symbol 'checkbox-off))
+        'face 'telega-link
+        'action (lambda (_button)
+                  (telega--setScopeNotificationSettings scope-type
+                    :mute_stories (if mute-stories-p :false t))))
+      (telega-ins " " "Mute Stories")
+      (telega-ins "\n"))
 
-    (telega-ins--button (if disable-mentions-p
-                            telega-symbol-heavy-checkmark
-                          telega-symbol-blank-button)
-      :value (if disable-mentions-p :false t)
-      :action (apply-partially #'telega--setScopeNotificationSettings
-                               scope-type :disable_mention_notifications))
-    (telega-ins " " "Disable Mention Notification")
-    (telega-ins "\n")
+    (let ((show-story-poster-p (plist-get sconf :show_story_poster)))
+      (telega-ins--text-button (if show-story-poster-p
+                                   (telega-symbol 'checkbox-on)
+                                 (telega-symbol 'checkbox-off))
+        'face 'telega-link
+        'action (lambda (_button)
+                  (telega--setScopeNotificationSettings scope-type
+                    :show_story_poster (if show-story-poster-p :false t))))
+      (telega-ins " " "Show Story Sender")
+      (telega-ins "\n"))
 
-    (telega-ins "Sound: " (if (string-empty-p sound) "None" sound))
+    (let ((disable-pinned-p
+           (plist-get sconf :disable_pinned_message_notifications)))
+      (telega-ins--text-button (if disable-pinned-p
+                                   (telega-symbol 'checkbox-on)
+                                 (telega-symbol 'checkbox-off))
+        'face 'telega-link
+        'action (lambda (_button)
+                  (telega--setScopeNotificationSettings scope-type
+                    :disable_pinned_message_notifications
+                    (if disable-pinned-p :false t))))
+      (telega-ins " " "Disable Pinned Message Notification")
+      (telega-ins "\n"))
+
+    (let ((disable-mentions-p (plist-get sconf :disable_mention_notifications)))
+      (telega-ins--text-button (if disable-mentions-p
+                                   (telega-symbol 'checkbox-on)
+                                 (telega-symbol 'checkbox-off))
+        'face 'telega-link
+        'action (lambda (_button)
+                  (telega--setScopeNotificationSettings scope-type
+                    :disable_mention_notifications
+                    (if disable-mentions-p :false t))))
+      (telega-ins " " "Disable Mention Notification")
+      (telega-ins "\n"))
+
+    (telega-ins (telega-i18n "lng_notification_sound") ": "
+                sound-id)
     (telega-ins "\n")
 
     ;; Exceptions
     (when-let ((exception-chats
                 (telega--getChatNotificationSettingsExceptions scope-type)))
-      (telega-ins-fmt "Exceptions: %d chats\n" (length exception-chats))
-      (telega-ins--labeled "  " nil
+      (telega-ins-fmt "Exceptions: %d chats" (length exception-chats))
+      (telega-ins--line-wrap-prefix "  "
         (dolist (chat exception-chats)
+          (telega-ins "\n")
           (telega-button--insert 'telega-chat chat
             :inserter #'telega-ins--chat
-            :action #'telega-describe-chat)
-          (telega-ins "\n"))))
+            :action #'telega-describe-chat))))
     ))
 
 (defun telega-describe-notifications--inserter (&rest _ignored)
   "Inserter for notification settings."
-  (telega-ins "telega-notifications-mode: "
-              (if telega-notifications-mode
-                  "Enabled"
-                "Disabled")
-              "\n")
+  (telega-ins "telega-notifications-mode: ")
+  (telega-ins--with-face 'telega-shadow
+    (telega-ins (if telega-notifications-mode
+                    (telega-symbol 'checkbox-on)
+                  (telega-symbol 'checkbox-off))))
+  (telega-ins "\n")
   (unless telega-notifications-mode
     (telega-ins--help-message
      (telega-ins "To enable notifications run \
@@ -173,28 +208,30 @@ M-x telega-notifications-mode RET")))
 
   (telega-ins "\n")
   (telega-ins--with-face 'bold
-    (telega-ins "Private/Secret chats:\n"))
-  (telega-ins--labeled "  " nil
+    (telega-ins (telega-i18n "lng_notification_private_chats") "\n"))
+  (telega-ins--line-wrap-prefix "  "
     (telega-ins--notification-scope
      "notificationSettingsScopePrivateChats"))
-;  (telega-ins "\n")
-  ;; TODO: exceptions
+  (telega-ins "\n")
 
+  (telega-ins "\n")
   (telega-ins--with-face 'bold
-    (telega-ins "Group chats:\n"))
-  (telega-ins--labeled "  " nil
+    (telega-ins (telega-i18n "lng_notification_groups") "\n"))
+  (telega-ins--line-wrap-prefix "  "
     (telega-ins--notification-scope
      "notificationSettingsScopeGroupChats"))
-;  (telega-ins "\n")
+  (telega-ins "\n")
 
+  (telega-ins "\n")
   (telega-ins--with-face 'bold
-    (telega-ins "Channel chats:\n"))
-  (telega-ins--labeled "  " nil
+    (telega-ins (telega-i18n "lng_notification_channels") "\n"))
+  (telega-ins--line-wrap-prefix "  "
     (telega-ins--notification-scope
      "notificationSettingsScopeChannelChats"))
   (telega-ins "\n")
 
-  (telega-ins--button (telega-i18n "telega_reset_notifications")
+  (telega-ins "\n")
+  (telega-ins--box-button (telega-i18n "telega_reset_notifications")
     'action (lambda (_button)
               (when (yes-or-no-p (telega-i18n "telega_query_reset_notifications"))
                 (telega--resetAllNotificationSettings))))
@@ -256,11 +293,11 @@ FORCE is used for testing only, should not be used in real code."
          (chat-id (plist-get msg :chat_id))
          (chat (telega-chat-get chat-id)))
     (unless (and (not force) (telega-msg-seen-p msg chat))
+      (ring-insert telega--notification-messages-ring msg)
       (setq notify-args
             (append
              notify-args
-             (list :actions (list "default" "show message")
-                   :on-action `(lambda (&rest args)
+             (list :on-action `(lambda (&rest args)
                                  (x-focus-frame (telega-x-frame))
                                  (telega-chat--goto-msg
                                      (telega-chat-get ,chat-id)
@@ -273,7 +310,9 @@ FORCE is used for testing only, should not be used in real code."
                                     "📅 ")
                                   (if (telega-me-p chat)
                                       (telega-i18n "lng_notification_reminder")
-                                    (telega-chat-title chat 'with-username)))
+                                    (telega-ins--as-string
+                                     (telega-ins--msg-sender chat
+                                       :with-username-p t))))
                    :body (if (telega-chat-notification-setting chat :show_preview)
                              (telega-ins--as-string
                               (funcall telega-inserter-for-msg-notification msg))
@@ -287,45 +326,50 @@ FORCE is used for testing only, should not be used in real code."
       (telega-notifications--notify notify-args)
       ;; Workaround stuck notifications, force closing after
       ;; `telega-notifications-timeout' timeout
-      (run-with-timer telega-notifications-timeout nil
-                      'telega-notifications--close
-                      telega-notifications--last-id)
+      (when telega-notifications-timeout
+        (run-with-timer telega-notifications-timeout nil
+                        'telega-notifications--close
+                        telega-notifications--last-id))
       )))
 
+;;; ellit-org: notification-conditions
+;; Do *NOT* pop notification if:
+;;  0. Me is not member of the group chat, see
+;;     https://github.com/zevlg/telega.el/issues/224
+;;  1. Message is ignored by
+;;     [[#client-side-messages-ignoring][client side messages ignoring]]
+;;  2. Chat is muted and message does not contain unread mention or
+;;     mention notification is disabled for the chat
+;;  3. Message already has been read (see ~telega-msg-seen-p~)
+;;  4. Message is older than 1 min (to avoid popping up messages on
+;;     laptop wakeup)
+;;  5. Message is currently observable in a chatbuf, i.e. chatbuf
+;;     must be selected and focused.
+(defun telega-notifications-msg-notify-p (msg)
+  "Return non-nil if message MSG should pop-up notification."
+  (let ((chat (telega-msg-chat msg)))
+    (unless (or (not (telega-chat-match-p chat
+                       '(or (type private secret) me-is-member)))
+                (and (telega-chat-muted-p chat)
+                     (or (telega-chat-notification-setting
+                          chat :disable_mention_notifications)
+                         (not (plist-get msg :contains_unread_mention))))
+                (telega-msg-seen-p msg chat)
+                (with-telega-chatbuf chat
+                  (and (telega-chatbuf--msg-observable-p msg)
+                       (not (telega-chatbuf--history-state-get :newer-freezed)))))
+      t)))
+
 (defun telega-notifications-chat-message (msg)
   "Function intended to be added to `telega-chat-post-message-hook'."
-  ;;; ellit-org: notification-conditions
-  ;; Do *NOT* pop notification if:
-  ;;  0. Me is not member of the group chat, see
-  ;;     https://github.com/zevlg/telega.el/issues/224
-  ;;  1. Message is ignored by
-  ;;     [[#client-side-messages-ignoring][client side messages ignoring]]
-  ;;  2. Chat is muted and message does not contain unread mention or
-  ;;     mention notification is disabled for the chat
-  ;;  3. Message already has been read (see ~telega-msg-seen-p~)
-  ;;  4. Message is older than 1 min (to avoid popping up messages on
-  ;;     laptop wakeup)
-  ;;  5. Message is currently observable in a chatbuf, i.e. chatbuf
-  ;;     must be selected and focused in (not having
-  ;;     ~telega-chatbuf--refresh-point~)
-  (unless (or (telega-msg-ignored-p msg)
+  (unless (or (telega-msg-match-p msg 'ignored)
               (> (- (telega-time-seconds) (plist-get msg :date)) 60))
-    (let ((chat (telega-msg-chat msg)))
-      (unless (or (not (telega-chat-match-p chat
-                         '(or (type private secret) me-is-member)))
-                  (and (telega-chat-muted-p chat)
-                       (or (telega-chat-notification-setting
-                            chat :disable_mention_notifications)
-                           (not (plist-get msg :contains_unread_mention))))
-                  (telega-msg-seen-p msg chat)
-                  (and (not (with-telega-chatbuf chat
-                              telega-chatbuf--refresh-point))
-                       (telega-msg-observable-p msg chat)))
-        (if (> telega-notifications-delay 0)
-            (run-with-timer telega-notifications-delay nil
-                            'telega-notifications--chat-msg0 msg)
-          ;; No delay
-          (telega-notifications--chat-msg0 msg))))))
+    (when (telega-msg-match-p msg telega-notifications-msg-temex)
+      (if (> telega-notifications-delay 0)
+          (run-with-timer telega-notifications-delay nil
+                          'telega-notifications--chat-msg0 msg)
+        ;; No delay
+        (telega-notifications--chat-msg0 msg)))))
 
 (defun telega-notifications-incoming-call (call)
   "Function intended to be added to `telega-call-incoming-hook'."
@@ -339,7 +383,9 @@ FORCE is used for testing only, should not be used in real code."
                         :timeout 0
                         ;; I18N: lng_call_incoming
                         :title "Incoming call"
-                        :body (format "from %s" (telega-user--name user)))))
+                        :body (format "from %s" (telega-msg-sender-title user
+                                                  :with-avatar-p t
+                                                  :with-username-p t)))))
     (telega-notifications--notify
      (nconc notargs telega-notifications-call-args))))
 
@@ -354,6 +400,17 @@ FORCE is used for testing only, should not be used in real code."
     (remove-hook 'telega-chat-post-message-hook 'telega-notifications-chat-message)
     (remove-hook 'telega-call-incoming-hook 'telega-notifications-incoming-call)))
 
+(defun telega-notifications-history ()
+  "Show notifications history, most recent notification goes first."
+  (interactive)
+  (with-telega-help-win "*Telegram Notification Messages*"
+    (save-excursion
+      (dolist (msg (ring-elements telega--notification-messages-ring))
+        (telega-button--insert 'telega-msg msg
+          :inserter #'telega-ins--message-with-chat-header
+          :action #'telega-msg-goto-highlight)
+        (telega-ins "\n")))))
+
 (provide 'telega-notifications)
 
 
